import i18next from 'i18next';

interface UseFormatters {
    format: (formatString: string, value: unknown) => unknown;
}


export const useFormatters = (): UseFormatters => {
  const listFormatter = (value: unknown[]): string => value.join(', ');
  const boolFormatter = (value: boolean, truthyLabel = 'True', falsyLabel = 'False'): string => value ? truthyLabel : falsyLabel;
  const dateFormatter = (value: string, withTime?: boolean, locale?: string): string => {
    const date = new Date(value);
    const usedLocale = locale || i18next.language;
    return withTime ? date.toLocaleString(usedLocale) : date.toLocaleDateString(usedLocale);
  };

  const format = (formatString: string, value: unknown): unknown => {
    const formatterParts = formatString.split(':');
    switch (formatterParts[0]) {
    case 'list':
      return listFormatter(value as unknown[]);
    case 'boolean': {
      const truthyLabel = formatterParts[1] || undefined;
      const falsyLabel = formatterParts[2] || undefined;
      return boolFormatter(value as boolean, truthyLabel, falsyLabel);
    }
    case 'date': {
      const withTime = formatterParts[1] === 'true' || undefined;
      const locale = formatterParts[2] || undefined;
      return dateFormatter(value as string, withTime, locale);
    }
    default:
      return value;
    }
  };
  return {
    format,
  };
};
